==> jc-1.4.0.tar.gz: javax/swing/undo/StateEdit.h <==
// public class javax.swing.undo.StateEdit

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 61d010fed23a29ad javax_swing_undo_AbstractUndoableEdit
// @dep_class f3bc8510236f6142 javax_swing_undo_StateEdit

// header file dependencies
// @dep_header javax_swing_undo_AbstractUndoableEdit

#include "javax/swing/undo/AbstractUndoableEdit.h"

#ifndef _JC_javax_swing_undo_StateEdit_H_
#define _JC_javax_swing_undo_StateEdit_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_swing_undo_StateEditable$object;

// Typedefs
typedef struct _jc_javax_swing_undo_StateEdit$sub_refs	_jc_javax_swing_undo_StateEdit$sub_refs;
typedef struct _jc_javax_swing_undo_StateEdit$sub_nonrefs	_jc_javax_swing_undo_StateEdit$sub_nonrefs;
typedef struct _jc_javax_swing_undo_StateEdit$refs	_jc_javax_swing_undo_StateEdit$refs;
typedef struct _jc_javax_swing_undo_StateEdit$nonrefs	_jc_javax_swing_undo_StateEdit$nonrefs;
typedef struct _jc_javax_swing_undo_StateEdit$object	_jc_javax_swing_undo_StateEdit$object;

typedef struct _jc_javax_swing_undo_StateEdit$fields_struct	_jc_javax_swing_undo_StateEdit$fields_struct;
typedef const struct _jc_javax_swing_undo_StateEdit$vmethods	_jc_javax_swing_undo_StateEdit$vmethods;
typedef const struct _jc_javax_swing_undo_StateEdit$vtable	_jc_javax_swing_undo_StateEdit$vtable;
typedef const struct _jc_javax_swing_undo_StateEdit$vtype	_jc_javax_swing_undo_StateEdit$vtype;

// Class fields structure
struct _jc_javax_swing_undo_StateEdit$fields_struct {
	struct _jc_java_lang_String$object	*RCSID;
};
extern _jc_javax_swing_undo_StateEdit$fields_struct _jc_javax_swing_undo_StateEdit$class_fields;

// Constructors
extern void _jc_javax_swing_undo_StateEdit$method$_init$6141db1b44e5ed37(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *, struct _jc_object *);
extern void _jc_javax_swing_undo_StateEdit$method$_init$d55789dcc782039e(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *, struct _jc_object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_javax_swing_undo_StateEdit$method$end$d5ec7c830865cdfd(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_undo_StateEdit$method$getPresentationName$a7f1f486d311845d(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *);
extern void _jc_javax_swing_undo_StateEdit$method$init$82047c7e05c5176b(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *, struct _jc_object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_swing_undo_StateEdit$method$redo$25b0fd1adab70c30(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *);
extern void _jc_javax_swing_undo_StateEdit$method$removeRedundantState$3f755767181c5852(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *);
extern void _jc_javax_swing_undo_StateEdit$method$undo$2a1fa1bb5289512f(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_undo_StateEdit$method_info$end$d5ec7c830865cdfd;
extern _jc_method _jc_javax_swing_undo_StateEdit$method_info$getPresentationName$a7f1f486d311845d;
extern _jc_method _jc_javax_swing_undo_StateEdit$method_info$init$82047c7e05c5176b;
extern _jc_method _jc_javax_swing_undo_StateEdit$method_info$redo$25b0fd1adab70c30;
extern _jc_method _jc_javax_swing_undo_StateEdit$method_info$removeRedundantState$3f755767181c5852;
extern _jc_method _jc_javax_swing_undo_StateEdit$method_info$undo$2a1fa1bb5289512f;

// Virtual methods structure
struct _jc_javax_swing_undo_StateEdit$vmethods {
	void	(*end$d5ec7c830865cdfd)(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *);
	struct _jc_java_lang_String$object	*(*getPresentationName$a7f1f486d311845d)(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *);
	void	(*init$82047c7e05c5176b)(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *, struct _jc_object *, struct _jc_java_lang_String$object *);
	void	(*redo$25b0fd1adab70c30)(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *);
	void	(*removeRedundantState$3f755767181c5852)(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *);
	void	(*undo$2a1fa1bb5289512f)(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *);
};

// Vtable
struct _jc_javax_swing_undo_StateEdit$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_undo_AbstractUndoableEdit$vmethods	javax_swing_undo_AbstractUndoableEdit;
	_jc_javax_swing_undo_StateEdit$vmethods	javax_swing_undo_StateEdit;
};

// Vtype
struct _jc_javax_swing_undo_StateEdit$vtype {
	_jc_type			type;
	_jc_javax_swing_undo_StateEdit$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_undo_StateEdit$sub_refs {
	struct _jc_object	*object;
	struct _jc_java_util_Hashtable$object	*preState;
	struct _jc_java_util_Hashtable$object	*postState;
	struct _jc_java_lang_String$object	*undoRedoName;
};

// Reference instance fields (object)
struct _jc_javax_swing_undo_StateEdit$refs {
    _jc_javax_swing_undo_StateEdit$sub_refs	javax_swing_undo_StateEdit;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_refs	javax_swing_undo_AbstractUndoableEdit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_undo_StateEdit$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_undo_StateEdit$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_nonrefs	javax_swing_undo_AbstractUndoableEdit;
    _jc_javax_swing_undo_StateEdit$sub_nonrefs	javax_swing_undo_StateEdit;
};

// Object instance structure
struct _jc_javax_swing_undo_StateEdit$object {
	_jc_javax_swing_undo_StateEdit$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_undo_StateEdit$vtype	*vtype;
	_jc_javax_swing_undo_StateEdit$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_undo_StateEdit$vtype _jc_javax_swing_undo_StateEdit$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_undo_StateEdit, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_undo_StateEdit$class_object;

#endif	/* _JC_javax_swing_undo_StateEdit_H_ */

==> jc-1.4.6.tar.gz: javax/swing/undo/StateEdit.h <==
// public class javax.swing.undo.StateEdit

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 61d010fed23a29ad javax_swing_undo_AbstractUndoableEdit
// @dep_class f3bc8510236f6142 javax_swing_undo_StateEdit

// header file dependencies
// @dep_header javax_swing_undo_AbstractUndoableEdit

#include "javax/swing/undo/AbstractUndoableEdit.h"

#ifndef _JC_javax_swing_undo_StateEdit_H_
#define _JC_javax_swing_undo_StateEdit_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_swing_undo_StateEditable$object;

// Typedefs
typedef struct _jc_javax_swing_undo_StateEdit$sub_refs	_jc_javax_swing_undo_StateEdit$sub_refs;
typedef struct _jc_javax_swing_undo_StateEdit$sub_nonrefs	_jc_javax_swing_undo_StateEdit$sub_nonrefs;
typedef struct _jc_javax_swing_undo_StateEdit$refs	_jc_javax_swing_undo_StateEdit$refs;
typedef struct _jc_javax_swing_undo_StateEdit$nonrefs	_jc_javax_swing_undo_StateEdit$nonrefs;
typedef struct _jc_javax_swing_undo_StateEdit$object	_jc_javax_swing_undo_StateEdit$object;

typedef struct _jc_javax_swing_undo_StateEdit$fields_struct	_jc_javax_swing_undo_StateEdit$fields_struct;
typedef const struct _jc_javax_swing_undo_StateEdit$vmethods	_jc_javax_swing_undo_StateEdit$vmethods;
typedef const struct _jc_javax_swing_undo_StateEdit$vtable	_jc_javax_swing_undo_StateEdit$vtable;
typedef const struct _jc_javax_swing_undo_StateEdit$vtype	_jc_javax_swing_undo_StateEdit$vtype;

// Class fields structure
struct _jc_javax_swing_undo_StateEdit$fields_struct {
	struct _jc_java_lang_String$object	*RCSID;
};
extern _jc_javax_swing_undo_StateEdit$fields_struct _jc_javax_swing_undo_StateEdit$class_fields;

// Constructors
extern void _jc_javax_swing_undo_StateEdit$method$_init$6141db1b44e5ed37(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_undo_StateEdit$method$_init$d55789dcc782039e(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_undo_StateEdit$method$end$d5ec7c830865cdfd(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_undo_StateEdit$method$getPresentationName$a7f1f486d311845d(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_undo_StateEdit$method$init$82047c7e05c5176b(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_undo_StateEdit$method$redo$25b0fd1adab70c30(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_undo_StateEdit$method$removeRedundantState$3f755767181c5852(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_undo_StateEdit$method$undo$2a1fa1bb5289512f(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_undo_StateEdit$method_info$end$d5ec7c830865cdfd;
extern _jc_method _jc_javax_swing_undo_StateEdit$method_info$getPresentationName$a7f1f486d311845d;
extern _jc_method _jc_javax_swing_undo_StateEdit$method_info$init$82047c7e05c5176b;
extern _jc_method _jc_javax_swing_undo_StateEdit$method_info$redo$25b0fd1adab70c30;
extern _jc_method _jc_javax_swing_undo_StateEdit$method_info$removeRedundantState$3f755767181c5852;
extern _jc_method _jc_javax_swing_undo_StateEdit$method_info$undo$2a1fa1bb5289512f;

// Virtual methods structure
struct _jc_javax_swing_undo_StateEdit$vmethods {
	void	(*end$d5ec7c830865cdfd)(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPresentationName$a7f1f486d311845d)(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *) _JC_JCNI_ATTR;
	void	(*init$82047c7e05c5176b)(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*redo$25b0fd1adab70c30)(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *) _JC_JCNI_ATTR;
	void	(*removeRedundantState$3f755767181c5852)(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *) _JC_JCNI_ATTR;
	void	(*undo$2a1fa1bb5289512f)(_jc_env *, struct _jc_javax_swing_undo_StateEdit$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_undo_StateEdit$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_undo_AbstractUndoableEdit$vmethods	javax_swing_undo_AbstractUndoableEdit;
	_jc_javax_swing_undo_StateEdit$vmethods	javax_swing_undo_StateEdit;
};

// Vtype
struct _jc_javax_swing_undo_StateEdit$vtype {
	_jc_type			type;
	_jc_javax_swing_undo_StateEdit$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_undo_StateEdit$sub_refs {
	struct _jc_object	*object;
	struct _jc_java_util_Hashtable$object	*preState;
	struct _jc_java_util_Hashtable$object	*postState;
	struct _jc_java_lang_String$object	*undoRedoName;
};

// Reference instance fields (object)
struct _jc_javax_swing_undo_StateEdit$refs {
    _jc_javax_swing_undo_StateEdit$sub_refs	javax_swing_undo_StateEdit;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_refs	javax_swing_undo_AbstractUndoableEdit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_undo_StateEdit$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_undo_StateEdit$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_nonrefs	javax_swing_undo_AbstractUndoableEdit;
    _jc_javax_swing_undo_StateEdit$sub_nonrefs	javax_swing_undo_StateEdit;
};

// Object instance structure
struct _jc_javax_swing_undo_StateEdit$object {
	_jc_javax_swing_undo_StateEdit$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_undo_StateEdit$vtype	*vtype;
	_jc_javax_swing_undo_StateEdit$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_undo_StateEdit$vtype _jc_javax_swing_undo_StateEdit$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_undo_StateEdit, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_undo_StateEdit$class_object;

#endif	/* _JC_javax_swing_undo_StateEdit_H_ */
